pub struct StateTracker { /* private fields */ }Expand description
Receives state updates from functioning parts of any program and proceeds to output them through an UnixDatagram socket.
The purpose which it full-fills is to allow microservices to communicate the current state of all their functionalities easily through a standardized way.
Implementations
Sourceimpl StateTracker
impl StateTracker
Sourcepub fn try_new(
output_sender_path: &str,
output_receiver_path: &str,
receiver: Receiver<TrackedData>,
) -> Result<Self, Error>
pub fn try_new( output_sender_path: &str, output_receiver_path: &str, receiver: Receiver<TrackedData>, ) -> Result<Self, Error>
Tries to create an instance of StateTracker.
Arguments
output_sender_path- Path to the UnixDatagram socket that will send the outputs.output_receiver_path- Path to the UnixDatagram socket that will receive the outputs.receiver- Receiver of TrackedData objects.
pub async fn run(self)